@@ -27,6 +27,7 @@
 
 #include <gtk/gtkobject.h>
 #include <libgnomevfs/gnome-vfs-types.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
 
 /* NautilusFile is an object used to represent a single element of a
  * NautilusDirectory. It's lightweight and relies on NautilusDirectory
@@ -71,6 +72,7 @@ typedef enum {
 #define NAUTILUS_FILE_EMBLEM_NAME_CANT_READ "noread"
 #define NAUTILUS_FILE_EMBLEM_NAME_CANT_WRITE "nowrite"
 #define NAUTILUS_FILE_EMBLEM_NAME_TRASH "trash"
+#define NAUTILUS_FILE_EMBLEM_NAME_NOTE "note"
 
 typedef void (*NautilusFileCallback)          (NautilusFile  *file,
 				               gpointer       callback_data);
@@ -99,7 +101,7 @@ void                    nautilus_file_unref                             (Nautilu
 /* Monitor the file. */
 void                    nautilus_file_monitor_add                       (NautilusFile                   *file,
 									 gconstpointer                   client,
-									 GList                          *attributes);
+									 NautilusFileAttributes          attributes);
 void                    nautilus_file_monitor_remove                    (NautilusFile                   *file,
 									 gconstpointer                   client);
 
@@ -108,16 +110,16 @@ void                    nautilus_file_monitor_remove                    (Nautilu
  * to other attributes as well.
  */
 void                    nautilus_file_call_when_ready                   (NautilusFile                   *file,
-									 GList                          *attributes,
+									 NautilusFileAttributes          attributes,
 									 NautilusFileCallback            callback,
 									 gpointer                        callback_data);
 void                    nautilus_file_cancel_call_when_ready            (NautilusFile                   *file,
 									 NautilusFileCallback            callback,
 									 gpointer                        callback_data);
 gboolean                nautilus_file_check_if_ready                    (NautilusFile                   *file,
-									 GList                          *attributes);
+									 NautilusFileAttributes          attributes);
 void                    nautilus_file_invalidate_attributes             (NautilusFile                   *file,
-									 GList                          *attributes);
+									 NautilusFileAttributes          attributes);
 void                    nautilus_file_invalidate_all_attributes         (NautilusFile                   *file);
 
 /* Basic attributes for file objects. */
@@ -135,6 +137,8 @@ char *                  nautilus_file_get_mime_type                     (Nautilu
 gboolean                nautilus_file_is_mime_type                      (NautilusFile                   *file,
 									 const char                     *mime_type);
 gboolean                nautilus_file_is_symbolic_link                  (NautilusFile                   *file);
+char *                  nautilus_file_get_volume_free_space             (NautilusFile                   *file);
+char *                  nautilus_file_get_volume_name                   (NautilusFile                   *file);
 char *                  nautilus_file_get_symbolic_link_target_path     (NautilusFile                   *file);
 char *                  nautilus_file_get_symbolic_link_target_uri      (NautilusFile                   *file);
 gboolean                nautilus_file_is_broken_symbolic_link           (NautilusFile                   *file);
@@ -298,6 +302,10 @@ char *                  nautilus_file_get_drop_target_uri               (Nautilu
 /* Get custom icon (if specified by metadata or link contents) */
 char *                  nautilus_file_get_custom_icon                   (NautilusFile                   *file);
 
+
+/* Thumbnailing handling */
+gboolean                nautilus_file_is_thumbnailing                   (NautilusFile                   *file);
+
 /* Convenience functions for dealing with a list of NautilusFile objects that each have a ref.
  * These are just convenient names for functions that work on lists of GtkObject *.
  */
@@ -313,7 +321,7 @@ void                    nautilus_file_dump                              (Nautilu
 typedef struct NautilusFileDetails NautilusFileDetails;
 
 struct NautilusFile {
-	GtkObject parent_slot;
+	GObject parent_slot;
 	NautilusFileDetails *details;
 };
 
@@ -328,7 +336,7 @@ typedef enum {
 } NautilusDateType;
 
 typedef struct {
-	GtkObjectClass parent_slot;
+	GObjectClass parent_slot;
 	
 	/* Called when the file notices any change. */
 	void                  (* changed)                (NautilusFile *file);
@@ -337,33 +345,33 @@ typedef struct {
 	void                  (* updated_deep_count_in_progress) (NautilusFile *file);
 
 	/* Virtual functions (mainly used for trash directory). */
-	void                  (* monitor_add)            (NautilusFile         *file,
-							  gconstpointer         client,
-							  GList                *attributes);
-	void                  (* monitor_remove)         (NautilusFile         *file,
-							  gconstpointer         client);
-	void                  (* call_when_ready)        (NautilusFile         *file,
-							  GList                *attributes,
-							  NautilusFileCallback  callback,
-							  gpointer              callback_data);
-	void                  (* cancel_call_when_ready) (NautilusFile         *file,
-							  NautilusFileCallback  callback,
-							  gpointer              callback_data);
-	gboolean              (* check_if_ready)         (NautilusFile         *file,
-							  GList                *attributes);
-	GnomeVFSFileType      (* get_file_type)          (NautilusFile         *file);
-	gboolean              (* get_item_count)         (NautilusFile         *file,
-							  guint                *count,
-							  gboolean             *count_unreadable);
-	NautilusRequestStatus (* get_deep_counts)        (NautilusFile         *file,
-							  guint                *directory_count,
-							  guint                *file_count,
-							  guint                *unreadable_directory_count,
-							  GnomeVFSFileSize     *total_size);
-	gboolean              (* get_date)               (NautilusFile         *file,
-							  NautilusDateType      type,
-							  time_t               *date);
-	char *                (* get_where_string)       (NautilusFile         *file);
+	void                  (* monitor_add)            (NautilusFile           *file,
+							  gconstpointer           client,
+							  NautilusFileAttributes  attributes);
+	void                  (* monitor_remove)         (NautilusFile           *file,
+							  gconstpointer           client);
+	void                  (* call_when_ready)        (NautilusFile           *file,
+							  NautilusFileAttributes  attributes,
+							  NautilusFileCallback    callback,
+							  gpointer                callback_data);
+	void                  (* cancel_call_when_ready) (NautilusFile           *file,
+							  NautilusFileCallback    callback,
+							  gpointer                callback_data);
+	gboolean              (* check_if_ready)         (NautilusFile           *file,
+							  NautilusFileAttributes  attributes);
+	GnomeVFSFileType      (* get_file_type)          (NautilusFile           *file);
+	gboolean              (* get_item_count)         (NautilusFile           *file,
+							  guint                  *count,
+							  gboolean               *count_unreadable);
+	NautilusRequestStatus (* get_deep_counts)        (NautilusFile           *file,
+							  guint                  *directory_count,
+							  guint                  *file_count,
+							  guint                  *unreadable_directory_count,
+							  GnomeVFSFileSize       *total_size);
+	gboolean              (* get_date)               (NautilusFile           *file,
+							  NautilusDateType        type,
+							  time_t                 *date);
+	char *                (* get_where_string)       (NautilusFile           *file);
 } NautilusFileClass;
 
 #endif /* NAUTILUS_FILE_H */
