@@ -28,6 +28,7 @@
 
 
 #include <config.h>
+#include <math.h>
 #include "nautilus-icon-dnd.h"
 
 #include "nautilus-file-dnd.h"
@@ -56,7 +57,6 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <math.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -811,7 +811,7 @@ handle_local_move (NautilusIconContainer *container,
 				(container, icon,
 				 world_x + item->icon_x, world_y + item->icon_y,
 				 icon->scale_x, icon->scale_y,
-				 TRUE, TRUE);
+				 TRUE, TRUE, TRUE);
 		}
 		moved_icons = g_list_prepend (moved_icons, icon);
 	}		
