@@ -121,6 +121,7 @@ static void     volume_unmounted_callback                         (NautilusVolum
 								   FMDesktopIconView      *icon_view);
 static void     update_desktop_directory                          (UpdateType              type);
 static gboolean real_supports_auto_layout                         (FMIconView             *view);
+static gboolean real_supports_keep_aligned                        (FMIconView             *view);
 static void     real_merge_menus                                  (FMDirectoryView        *view);
 static void     real_update_menus                                 (FMDirectoryView        *view);
 static gboolean real_supports_zooming                             (FMDirectoryView        *view);
@@ -300,6 +301,7 @@ fm_desktop_icon_view_class_init (FMDesktopIconViewClass *class)
 	FM_DIRECTORY_VIEW_CLASS (class)->supports_zooming = real_supports_zooming;
 
 	FM_ICON_VIEW_CLASS (class)->supports_auto_layout = real_supports_auto_layout;
+	FM_ICON_VIEW_CLASS (class)->supports_keep_aligned = real_supports_keep_aligned;
 }
 
 static void
@@ -875,12 +877,14 @@ volume_ops_callback (BonoboUIComponent *component, gpointer data, const char *ve
 	
 	file = NAUTILUS_FILE (selection->data);
 	
-	if (!nautilus_file_is_local (file)) {
+	uri = nautilus_file_get_uri (file);
+	if (!eel_str_has_prefix (uri, "file:")) {
+		/* Don't allow volume ops on remote uris */
+		g_free (uri);
 		nautilus_file_list_free (selection);
 		return;
 	}
-		
-	uri = nautilus_file_get_uri (file);
+	
 	mount_uri = nautilus_link_local_get_link_uri (uri);
 	mount_path = gnome_vfs_get_local_path_from_uri (mount_uri);
 	g_free (uri);
@@ -1470,6 +1474,12 @@ real_supports_auto_layout (FMIconView *view)
 	return FALSE;
 }
 
+static gboolean
+real_supports_keep_aligned (FMIconView *view)
+{
+	return TRUE;
+}
+
 static gboolean
 real_supports_zooming (FMDirectoryView *view)
 {
