@@ -89,7 +89,7 @@ struct NautilusZoomControlDetails {
 
 static guint signals[LAST_SIGNAL];
 
-gpointer accessible_parent_class;
+static gpointer accessible_parent_class;
 
 static const char *nautilus_zoom_control_accessible_action_names[] = {
 	N_("Zoom In"),
@@ -121,7 +121,7 @@ static GType nautilus_zoom_control_accessible_get_type (void);
 #define NUM_ACTIONS ((int)G_N_ELEMENTS (nautilus_zoom_control_accessible_action_names))
 
 GNOME_CLASS_BOILERPLATE (NautilusZoomControl, nautilus_zoom_control,
-			 GtkEventBox, GTK_TYPE_EVENT_BOX)
+			 EelInputEventBox, EEL_TYPE_INPUT_EVENT_BOX)
 
 static void
 nautilus_zoom_control_finalize (GObject *object)
@@ -154,7 +154,6 @@ static void
 nautilus_zoom_control_instance_init (NautilusZoomControl *zoom_control)
 {
 	GTK_WIDGET_SET_FLAGS (zoom_control, GTK_CAN_FOCUS);
-	GTK_WIDGET_UNSET_FLAGS (zoom_control, GTK_NO_WINDOW);
 
 	gtk_widget_add_events (GTK_WIDGET (zoom_control), 
 			       GDK_BUTTON_PRESS_MASK
@@ -371,7 +370,8 @@ nautilus_zoom_control_expose (GtkWidget *widget, GdkEventExpose *event)
 	g_return_val_if_fail (widget != NULL, FALSE);
 	g_return_val_if_fail (NAUTILUS_IS_ZOOM_CONTROL (widget), FALSE);
 
-	box.x = 0; box.y = 0;
+	box.x = widget->allocation.x;
+	box.y = widget->allocation.y;
 	box.width = widget->allocation.width;
 	box.height = widget->allocation.height;
 
@@ -752,6 +752,8 @@ nautilus_zoom_control_set_parameters (NautilusZoomControl *zoom_control,
 				      gboolean has_max_zoom_level,
 				      GList *zoom_levels)
 {
+	g_return_if_fail (NAUTILUS_IS_ZOOM_CONTROL (zoom_control));
+	
 	zoom_control->details->min_zoom_level = min_zoom_level;
 	zoom_control->details->max_zoom_level = max_zoom_level;
 	zoom_control->details->has_min_zoom_level = has_min_zoom_level;
@@ -1088,6 +1090,16 @@ nautilus_zoom_control_accessible_get_description (AtkObject *accessible)
 	return _("Set the zoom level of the current view");
 }
 
+static void
+nautilus_zoom_control_accessible_initialize (AtkObject *accessible,
+                                             gpointer  data)
+{
+	if (ATK_OBJECT_CLASS (accessible_parent_class)->initialize != NULL) {
+		ATK_OBJECT_CLASS (accessible_parent_class)->initialize (accessible, data);
+	}
+	atk_object_set_role (accessible, ATK_ROLE_DIAL);	
+}
+
 static void
 nautilus_zoom_control_accessible_class_init (AtkObjectClass *klass)
 {	
@@ -1095,6 +1107,7 @@ nautilus_zoom_control_accessible_class_init (AtkObjectClass *klass)
 
 	klass->get_name = nautilus_zoom_control_accessible_get_name;
 	klass->get_description = nautilus_zoom_control_accessible_get_description;
+	klass->initialize = nautilus_zoom_control_accessible_initialize;
 }
 
 static GType
@@ -1117,7 +1130,7 @@ nautilus_zoom_control_accessible_get_type (void)
 		
 		type = eel_accessibility_create_derived_type
 			("NautilusZoomControlAccessible",
-			 GTK_TYPE_EVENT_BOX,
+			 EEL_TYPE_INPUT_EVENT_BOX,
 			 nautilus_zoom_control_accessible_class_init);
 		
  		g_type_add_interface_static (type, ATK_TYPE_ACTION,
